/**
 * MeetingsNewStepOneController.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('controllers/meetings/newstepone/meetingsnewsteponecontroller',
		['app',
		 'utils/validationutils',
		 'nls/i18nhelper',
		 'ember',
		 'cordova',
		 'models/meeting/meeting'],
		 function(Filmeet, ValidationUtils, I18nHelper){
	console.log('Defining MeetingsNewStepOneController');
	Filmeet.MeetingsNewStepOneController = Ember.Controller.extend({
		// Properties
		/** Meeting's name */
		name: null,
		/** Meeting's day */
		day: [],
		/** Meeting's selected day */
		selectedDay: null,
		/** Meeting's month */
		month: [],
		/** Meeting's selected month */
		selectedMonth: null,
		/** Meeting's year */
		year: [],
		/** Meeting's selected year */
		selectedYear: null,
		/** Meeting's hour */
		hour: [],
		/** Meeting's selected hour */
		selectedHour: null,
		/** Meeting's minutes */
		minutes: [],
		/** Meeting's selected minutes */
		selectedMinutes: null,
		/** Meeting's number of film candidates */
		numCandidates: null,
		/** Filter for in cinema films */
		checkedInCinema: false,
		/** Filter for not seen films */
		checkedNotSeen: false,
		// Functions
		/** Populates the data to create the new meeting and goes to the second step */
		goToStepTwo: function(){
			//Populating data
			var name = this.get('name');
			var day = this.get('selectedDay');
			var month = this.get('selectedMonth').get('monthNumber')-1;
			var year = this.get('selectedYear');
			
			var hours = this.get('selectedHour');
			var minutes = this.get('selectedMinutes');
			
			var date = new Date(year, month, day, hours, minutes, 0, 0);
			
			var numberCandidates = this.get('numCandidates');
			var inCinema = this.get('checkedInCinema');
			var notSeen = this.get('checkedNotSeen');
			
			// Validating data
			var isEmptyName = ValidationUtils.isEmptyOrNullString(name);
			var isFutureDate = ValidationUtils.isDateAfterNow(date);
			var isValidNumCandidates = ValidationUtils.isNumber(numberCandidates);
			var isMoreZeroCandidate = numberCandidates > 0;
			var isLessOrEqualFiveCandidates = numberCandidates <= 5;
			
			// If everything is correct, then go to the next step. If not, show a message error.
			if(!isEmptyName
					&& isFutureDate
					&& isValidNumCandidates
					&& isMoreZeroCandidate
					&& isLessOrEqualFiveCandidates){
				var newMeeting = Filmeet.Meeting.create({
					name: name,
					date: date,
					numberCandidates: numberCandidates,
					inCinema: inCinema,
					notSeen: notSeen
				});
				
				this.transitionToRoute('meetings.newStepTwo', newMeeting);
			} else {
				var errorsMsg = "";
				if(isEmptyName){
					errorsMsg = I18nHelper.getValueFromKey('errorNoMeetingName');
					if(!isFutureDate
							|| !isValidNumCandidates
							|| !isMoreZeroCandidate
							|| !isLessOrEqualFiveCandidates){
						errorsMsg = errorsMsg + "\n";
					}
				}
				
				if(!isFutureDate){
					errorsMsg = errorsMsg + I18nHelper.getValueFromKey('errorNotFutureDate');
					if(!isValidNumCandidates
							|| !isMoreZeroCandidate
							|| !isLessOrEqualFiveCandidates){
						errorsMsg = errorsMsg + "\n";
					}
				}
				
				if(!isValidNumCandidates){
					errorsMsg = errorsMsg + I18nHelper.getValueFromKey('errorInvalidNumCandidate');
					if(!isMoreZeroCandidate
							|| !isLessOrEqualFiveCandidates){
						errorsMsg = errorsMsg + "\n";
					}
				}
				
				if(!isMoreZeroCandidate){
					errorsMsg = errorsMsg + I18nHelper.getValueFromKey('errorAtLeastOneCandidate');
					if(!isLessOrEqualFiveCandidates){
						errorsMsg = errorsMsg + "\n";
					}
				}
				
				if(!isLessOrEqualFiveCandidates){
					errorsMsg = errorsMsg + I18nHelper.getValueFromKey('errorNotMoreFiveCandidates');
				}
				
				navigator.notification.alert(errorsMsg, function(){}, I18nHelper.getValueFromKey('errors'));
			}
		}
	});
});