/**
 * OneMeetingVoteController.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('controllers/meetings/vote/onemeetingvotecontroller',
		['app',
		 'nls/i18nhelper',
		 'shared/urlcatalog',
		 'shared/keys',
		 'ember',
		 'models/film/film'],
		 function(Filmeet, I18nHelper, UrlCatalog, Keys){
	console.log('Defining OneMeetingVoteController');
	Filmeet.OneMeetingVoteController = Ember.ObjectController.extend({
		maxNumCandidates: null,
		films: [],
		selectedFilms: [],
		searchText: null,
		initProperties: function(){
			var meeting = this.get('content');
			if(meeting && meeting.get('sid') != null){
				this.searchFilms();
			}
			if(meeting && meeting.get('numberCandidates') != null){
				this.set('maxNumCandidates', meeting.get('numberCandidates'));
			}
		}.observes('content.sid','content.numberCandidates'),
		voteFilms: function(){
			var self = this;
			var meeting = self.get('content');
			var numCandidates = meeting.get('numberCandidates');
			var selectedFilms = self.get('selectedFilms');
			
			if(selectedFilms.length > 0
					&& selectedFilms.length <= numCandidates){
				
				var filmSidList = [];
				for(var i = 0; i < selectedFilms.length; i++){
					filmSidList.push(selectedFilms[i].get('sid'));
				}
				
				$.ajax({
					type: 'POST',
					cache: false,
					url: UrlCatalog.get('vote'),
					data: {'meetingSid': meeting.get('sid'),
						'filmSidList': filmSidList,
						'hash': localStorage.getItem(Keys.authorizationHash)
					},
					success: function(){
						self.transitionToRoute('oneMeeting.details', meeting.get('sid'));
					}
				});
				
			} else {
				if(selectedFilms.length <= 0){
					navigator.notification.alert(I18nHelper.getValueFromKey('errorAtLeastOneFilm'), function(){}, I18nHelper.getValueFromKey('errors'));
				} else {
					navigator.notification.alert(I18nHelper.getValueFromKey('errorMaxFilms')+' '+numCandidates+'.', function(){}, I18nHelper.getValueFromKey('errors'));
				}
				
			}
		},
		addToVotingList: function(film){
			if(!this.get('selectedFilms').contains(film)){
				this.get('selectedFilms').addObject(film);
				this.get('films').removeObject(film);
				var maxNumCand = this.get('maxNumCandidates');
				this.set('maxNumCandidates', maxNumCand-1);
			}
		},
		deleteFromVotingList: function(film){
			this.get('selectedFilms').removeObject(film);
			this.get('films').addObject(film);
			var maxNumCand = this.get('maxNumCandidates');
			this.set('maxNumCandidates', maxNumCand+1);
		},
		searchFilms: function(){
			var searchedText = this.get('searchText');
			var meeting = this.get('content');
			this.set('films', Filmeet.Film.getCandidates(searchedText, meeting.get('sid')));
		}.observes('searchText'),
		isOneCandidate: function(){
			var maxNumCand = this.get('maxNumCandidates');
			if(maxNumCand <= 1){
				return true;
			} else {
				return false;
			}
		}.property('maxNumCandidates'),
		isCandidates: function(){
			var maxNumCand = this.get('maxNumCandidates');
			if(maxNumCand > 0){
				return true;
			} else {
				return false;
			}
		}.property('maxNumCandidates')
	});
});